@@ -599,7 +599,7 @@ ClingoControl::~ClingoControl() noexcept = default;
 // {{{1 definition of ClingoSolveFuture
 
 SolveResult convert(Clasp::ClaspFacade::Result res) {
-    if (res.interrupted() && res.signal != 0 && res.signal != 65) {
+    if (res.interrupted() && res.signal != 0 && res.signal != 9 && res.signal != 65) {
         throw std::runtime_error("solving stopped by signal");
     }
     SolveResult::Satisfiabily sat = SolveResult::Satisfiable;
@@ -667,7 +667,7 @@ void ClingoLib::initOptions(Potassco::ProgramOptions::OptionContext& root) {
     OptionGroup gringo("Gringo Options");
     gringo.addOptions()
         ("verbose,V"                , flag(grOpts_.verbose = false), "Enable verbose output")
-        ("const,c"                  , storeTo(grOpts_.defines, parseConst)->composing()->arg("<id>=<term>"), "Replace term occurences of <id> with <term>")
+        ("const,c"                  , storeTo(grOpts_.defines, parseConst)->composing()->arg("<id>=<term>"), "Replace term occurrences of <id> with <term>")
         ("output-debug", storeTo(grOpts_.outputOptions.debug = Output::OutputDebug::NONE, values<Output::OutputDebug>()
           ("none", Output::OutputDebug::NONE)
           ("text", Output::OutputDebug::TEXT)
